# Using this template

Please make sure to create a `.env` file with your OpenAI API key before running the project.
OPENAI_API_KEY=sk-xxxxxxx

## Running
You can first test your app locally by using by running `python app.py`, after experimenting, send it to evaluation by running `agenta up folder`.
You will find then the app in the dashboard, where you can evaluate it and compare it to previous versions.

